/*
 * Package:    gui
 * File:       Graph.java
 * Created on: 16.01.2005
 *
 */
package gui;

import java.awt.Color;
import java.awt.Graphics;

import javax.swing.JComponent;

/**
 * @author Ape
 */
public class Graph extends JComponent {
	public static final int LINE_STYLE =	0;
	public static final int BAR_STYLE =		1;
	
	double values[];
	
	double maxY, incX, incY;
	boolean showGrid, showLabels;
	int style = BAR_STYLE;
	
	public Graph(int valueCnt, double maxY, double incX, double incY, boolean showGrid, boolean showLabels) {
		values = new double[valueCnt];
		for(int i=0; i<valueCnt; i++) {
			values[i] = 0;
		}
		
		this.maxY = maxY;
		this.incX = incX;
		this.incY = incY;
		this.showGrid = showGrid;
		this.showLabels = showLabels;
	}
	
	public void paint(Graphics g) {
		int w = getWidth(), h = getHeight()-1;
		
		g.setColor(Color.white);
		g.fillRect(0,0,w,h);
		
		if(showGrid) {
			g.setColor(new Color(200,200,200));
			double x = 0;
			while(x < w) {
				x += (double)w/((double)values.length/incX);
				g.drawLine((int)x,0,(int)x,h);
			}
			double y = 0;
			while(y < h) {
				y += ((double)h*incY)/maxY;
				g.drawLine(0,(int)y,w,(int)y);
			}
		}
		
		g.setColor(Color.blue);
		if(style == LINE_STYLE) {
			double lastV = values[0];
			int lastY = (int)((double)h*(values[0])/maxY);
			double inc = (double)w/((double)values.length-1);
			
			for(int i=1; i<values.length; i++) {
				int y = (int)((double)h*(values[i])/maxY);
				g.drawLine((int)(inc*(i-1)), h-lastY, (int)(inc*i), h-y);
				lastY = y;
			}
		} else {
			double inc = (double)w/((double)values.length-1);
			int barW = (int)Math.round(inc*2.0/3.0);
			for(int i=0; i<values.length; i++) {
				int y = (int)((double)h*(values[i])/maxY);
				g.fillRect((int)(i*inc), h-(y+3), (int)(barW), y);
			}
		}
		
		g.setColor(new Color(150,150,150));
		g.drawRect(0,0,w,h+1);
	}
	
	public void setValues(double[] v) {
		for(int i=0; i<v.length; i++) {
			values[i] = v[i];
		}
		repaint();
	}
}
