/*
 * Package:    gui
 * File:       MainWindow.java
 * Created on: 16.01.2005
 *
 */
package gui;

import java.awt.Dimension;
import java.awt.Toolkit;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;

import javax.swing.JFrame;

import comm.AVRReader;

/**
 * @author Ape
 */
public class MainWindow extends JFrame {
	private Graph g;
	AVRReader reader;
	
	public MainWindow(String port) {
		initGUI();
		initFrame();
		
		reader = new AVRReader(this, port);
	}

	private void initFrame() {
		setTitle("Spectrum Analyser Test");
		setSize(640,480);
		Dimension d = Toolkit.getDefaultToolkit().getScreenSize();
		setLocation((d.width-getWidth())/2, (d.height-getHeight())/2);

		addWindowListener(new WindowAdapter() {
			public void windowClosing(WindowEvent e) {
				System.out.println("close");
				reader.stop();
				
				try {
					Thread.sleep(100);
				} catch(Exception ex) {}
				System.exit(0);
			}
		});
		
		setVisible(true);
	}

	private void initGUI() {
		g = new Graph(63, 160, 8, 32, true, true);
		getContentPane().add("Center", g);
		
		double values[] = new double[63];
		for(int i=0; i<63; i++) {
			values[i] = Math.sin((Math.PI/32)*i)*100+128;
		}
	}

	public void setValues(double[] values) {
		g.setValues(values);
	}
	
	public static void main(String args[]) {
		if(args.length != 1) {
			System.out.println("usage: java -classpath .;comm.jar gui.MainWindow [COM-Port]");
		}
		new MainWindow(args[0]);
	}
}
